@@ -23,12 +23,16 @@ cp build-files/libmosquitto.control debian/control
 cp build-files/libmosquitto.rules debian/rules
 cp build-files/libmosquitto.install debian/
 
+# Fix the changelog to use the changelog we created.
 head -1 ./debian/changelog >dest.txt ; cat ./build-files/changelog >>dest.txt ; tail -2 ./debian/changelog | head -1 | sed 's/unknown/Yuvraaj Kelkar/g' >>dest.txt
 mv dest.txt ./debian/changelog
 
+# Fix the python library so that it can work in Maemo.
+sed 's/from ctypes import \*/from ctypes import \*\nc_bool = c_int/g' lib/python/mosquitto.py >mosquitto.py
+mv mosquitto.py lib/python/mosquitto.py
+
 dpkg-buildpackage -rfakeroot -sa -S
 dput -f $1-extras-builder ../libmosquitto*.changes
 #dpkg-buildpackage -rfakeroot
 
 popd
-
